'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.findSectorByRelativePosition = exports.hoveredSection = exports.chart = undefined;

var _reselect = require('reselect');

var _selectors = require('../user/transactions/selectors');

var chart = exports.chart = function chart(state) {
  return state.chart;
};

var hoveredSection = exports.hoveredSection = (0, _reselect.createSelector)(chart, function (chart) {
  return chart.hovered;
});

var findSectorByRelativePosition = exports.findSectorByRelativePosition = (0, _reselect.createSelector)([chart, _selectors.sectors], function (chart, sectors) {
  return function (pageX, pageY) {
    // находим относительные позиции, относительно центра графика
    var radius = 15;
    var radius3 = 16;
    var x = pageX - chart.x - radius;
    var y = -(pageY - chart.y - radius);

    var position = x * x + y * y;
    // если кликаем вне круга, то возвращаем null
    if (position > radius * radius || position < radius3 * radius3) {
      return null;
    }

    var absX = Math.abs(x);
    var absY = Math.abs(y);
    var angle = void 0;
    if (x >= 0 && y < 0) {
      angle = Math.atan(absY / absX);
    } else if (x < 0 && y < 0) {
      angle = Math.PI / 2 + Math.atan(absX / absY);
    } else if (x < 0 && y >= 0) {
      angle = Math.PI + Math.atan(absY / absX);
    } else if (x >= 0 && y >= 0) {
      angle = 3 * Math.PI / 2 + Math.atan(absX / absY);
    }

    return sectors.find(function (_ref) {
      var startAngle = _ref.startAngle,
          endAngle = _ref.endAngle;
      return startAngle < angle && endAngle >= angle;
    });
  };
});