'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _immutable = require('immutable');

var _reducer = require('../reducer');

var _reducer2 = _interopRequireDefault(_reducer);

var _actions = require('../actions');

var _I18n = require('../I18n');

var _I18n2 = _interopRequireDefault(_I18n);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var getState = function getState() {
  var i18n = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var blockName = arguments[1];
  var block = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

  var state = new _I18n2.default(_extends({
    language: 'te'
  }, i18n));
  if (blockName) {
    return state.set('domains', state.get('domains').set(blockName, new _I18n.I18nBlock(block)));
  }
  return state;
};

describe('I18N reducer', function () {
  it('initial state', function () {
    expect((0, _reducer2.default)(undefined, {})).toEqual(new _I18n2.default());
  });

  it('onI18nFetch', function () {
    expect((0, _reducer2.default)(undefined, (0, _actions.onI18nFetch)('ru', '/login'))).toEqual(new _I18n2.default().setIn(['domains', '/login'], new _I18n.I18nBlock({ isLoading: true })));
  });

  it('onI18nFetch.success', function () {
    var payload = { data: { data: { test: 'test' } } };
    var meta = { previousAction: { payload: { request: { url: '/translations/ku/login' } } } };
    expect((0, _reducer2.default)(getState(undefined, '/login', { isLoading: true, isLoaded: false }), _actions.onI18nFetch.success(payload, meta))).toEqual(getState(undefined, '/login', { isLoading: false, isLoaded: true, texts: (0, _immutable.Map)({ test: 'test' }) }));
  });

  it('onI18nFetch.error', function () {
    var payload = { data: { data: 'data' } };
    var meta = { previousAction: { payload: { request: { url: '/translations/ku/login' } } } };
    expect((0, _reducer2.default)(getState(undefined, '/login', { isLoading: true }), _actions.onI18nFetch.fail(payload, meta))).toEqual(getState(undefined, '/login', { isLoading: false }));
  });

  it('onChangeLanguage', function () {
    expect((0, _reducer2.default)(getState({ language: 'ru' }), (0, _actions.onChangeLanguage)('su'))).toEqual(getState({ language: 'su' }));
  });
});