'use strict';

var _immutable = require('immutable');

var _I18n = require('../I18n');

var _I18n2 = _interopRequireDefault(_I18n);

var _Router = require('../../router/Router');

var _selectors = require('../selectors');

var s = _interopRequireWildcard(_selectors);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var getState = function getState(block) {
  var state = {
    i18n: new _I18n2.default(),
    router: new _Router.Router({
      location: new _Router.Location({
        pathname: '/dashboard'
      })
    })
  };
  state.i18n = state.i18n.setIn(['domains', '/dashboard'], new _I18n.I18nBlock({ isLoaded: true, texts: (0, _immutable.Map)(block) }));
  return state;
};

describe('I18n selectors', function () {
  it('domains', function () {
    var state = getState();
    expect(s.domains(state)).toEqual(getState().i18n.get('domains'));
  });

  it('commonTranslations', function () {
    var state = getState();
    expect(s.commonTranslations(state)).toEqual(getState().i18n.get('domains').get('/common').get('texts'));
  });

  it('currentDomain', function () {
    var state = getState();
    expect(s.currentDomain(state)).toEqual(getState().i18n.get('domains').get('/dashboard'));
  });

  it('translations', function () {
    var trs = {
      test1: 'test1'
    };
    var state = getState(trs);
    expect(s.translations(state)).toEqual((0, _immutable.Map)(trs));
  });

  it('t translation NOT found', function () {
    var trs = {
      test1: 'test1'
    };
    var state = getState(trs);
    expect(s.t(state)('notFound')).toBe('notFound');
  });

  it('t translation found', function () {
    var trs = {
      test1: 'test1text'
    };
    var state = getState(trs);
    expect(s.t(state)('test1')).toBe('test1text');
  });

  it('texts translation found', function () {
    var trs = {
      test1: '1',
      test2: '2'
    };
    var state = getState(trs);
    expect(s.texts({ Login: 'test1', Reg: 'test2' })(state)).toEqual({
      Login: '1',
      Reg: '2'
    });
  });
});