'use strict';

var _reducer = require('../reducer');

var _reducer2 = _interopRequireDefault(_reducer);

var _User = require('../User');

var _User2 = _interopRequireDefault(_User);

var _UserReceivings = require('../receiving/UserReceivings');

var _UserSpendings = require('../spending/UserSpendings');

var _actions = require('../actions');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('User reducer', function () {
  it('should return the initial state', function () {
    var newState = (0, _reducer2.default)(undefined, {});
    expect(newState.isLoading).toBeFalsy();
    expect(newState.username).toBeNull();
  });

  it('should handle registerUser', function () {
    var newState = (0, _reducer2.default)(new _User2.default({ isLoading: false }), (0, _actions.registerUser)({ username: 'test' }));
    expect(newState.get('isLoading')).toBeTruthy();
    expect(newState.get('username')).toBe('test');
  });

  it('should handle registerUserSuccess', function () {
    var payload = {
      data: {
        username: 'test2',
        token: 'asdfasdfasdfasdfdasf'
      }
    };
    var newState = (0, _reducer2.default)(new _User2.default({ isLoading: true }), (0, _actions.registerUserSuccess)(payload));
    expect(newState.get('isLoading')).toBeFalsy();
    expect(newState.get('username')).toBe('test2');
    expect(newState.get('token')).toBe('asdfasdfasdfasdfdasf');
    expect(newState.get('receiving') instanceof _UserReceivings.UserReceivings).toBeTruthy();
    expect(newState.get('spending') instanceof _UserSpendings.UserSpendings).toBeTruthy();
  });

  it('should handle registerUserFail', function () {
    var newState = (0, _reducer2.default)(new _User2.default({ token: 'asdfasdfasdfasdf', isLoading: true }), (0, _actions.registerUserFail)());
    expect(newState.get('isLoading')).toBeFalsy();
    expect(newState.get('token')).toBeNull();
  });

  it('should handle loginUser', function () {
    var newState = (0, _reducer2.default)(new _User2.default(), (0, _actions.loginUser)({ username: 'testLogin' }));
    expect(newState.get('isLoading')).toBeTruthy();
    expect(newState.get('username')).toBe('testLogin');
  });

  it('should handle loginUserSuccess', function () {
    var data = {
      data: {
        username: 'test23',
        token: 'asdfasdfasdfasdfdasf2'
      }
    };
    var newState = (0, _reducer2.default)(new _User2.default({ isLoading: true, isAuth: false }), (0, _actions.loginUserSuccess)(data));
    expect(newState.get('isLoading')).toBeFalsy();
    expect(newState.get('isAuth')).toBeTruthy();
    expect(newState.get('username')).toBe('test23');
    expect(newState.get('token')).toBe('asdfasdfasdfasdfdasf2');
  });

  it('should handle loginUserFail', function () {
    var newState = (0, _reducer2.default)(new _User2.default({ token: 'asdfasdfasdfasdf', isLoading: true }), (0, _actions.loginUserFail)());
    expect(newState.get('isLoading')).toBeFalsy();
  });

  it('should handle refreshToken', function () {
    var newState = (0, _reducer2.default)(new _User2.default({ token: 'asdfasdfasdfasdf' }), (0, _actions.refreshToken)('newToken'));
    expect(newState.get('token')).toBe('newToken');
  });
});