'use strict';

var _immutable = require('immutable');

var _Operation = require('../Operation');

var _Operation2 = _interopRequireDefault(_Operation);

var _UserSpendings = require('../spending/UserSpendings');

var _UserReceivings = require('../receiving/UserReceivings');

var _selectors = require('../selectors');

var selectors = _interopRequireWildcard(_selectors);

var _userStoreMock = require('../__mocks__/userStoreMock');

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('User selectors', function () {
  it('isLoading selector', function () {
    expect(selectors.isLoading((0, _userStoreMock.getState)())).toBe('isLoading');
  });

  it('isAuth selector test', function () {
    expect(selectors.isAuth((0, _userStoreMock.getState)())).toBe('isAuth');
  });

  it('token selector test', function () {
    expect(selectors.token((0, _userStoreMock.getState)())).toBe('secretToken');
  });

  it('username selector test', function () {
    expect(selectors.username((0, _userStoreMock.getState)())).toBe('username');
  });

  it('initials selector test (username exists)', function () {
    expect(selectors.userState((0, _userStoreMock.getState)()).initials()).toBe('username');
  });

  it('initials selector test (username NOT exists)', function () {
    expect(selectors.userState((0, _userStoreMock.getState)({ email: 'email', username: '' })).initials()).toBe('email');
  });

  it('spending', function () {
    expect(selectors.spending((0, _userStoreMock.getState)())).toEqual((0, _immutable.List)([(0, _immutable.Map)({ id: 1 })]));
  });

  it('receiving', function () {
    expect(selectors.receiving((0, _userStoreMock.getState)())).toEqual((0, _immutable.List)([(0, _immutable.Map)({ id: 2 })]));
  });

  it('operations all empty', function () {
    expect(selectors.operations((0, _userStoreMock.getState)({
      spending: new _UserSpendings.UserSpendings(),
      receiving: new _UserReceivings.UserReceivings()
    }))).toEqual((0, _immutable.List)());
  });

  it('operations all empty', function () {
    var state = (0, _userStoreMock.getState)({
      spending: new _UserSpendings.UserSpendings(),
      receiving: new _UserReceivings.UserReceivings()
    });
    expect(selectors.operations(state).toJS()).toEqual([]);
  });

  it('operations all', function () {
    expect(selectors.operations((0, _userStoreMock.getState)())).toContainEqual(new _Operation2.default({
      id: 'debit1',
      type: 'debit'
    }));
    expect(selectors.operations((0, _userStoreMock.getState)())).toContainEqual(new _Operation2.default({
      id: 'credit2',
      type: 'credit'
    }));
  });
});