'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.operations = exports.receiving = exports.spending = exports.username = exports.isAuth = exports.isLoading = exports.token = exports.userState = undefined;

var _selectors = require('./ratios/selectors');

Object.keys(_selectors).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function get() {
      return _selectors[key];
    }
  });
});

var _reselect = require('reselect');

var _Operation = require('./Operation');

var _Operation2 = _interopRequireDefault(_Operation);

var _immutable = require('immutable');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var userState = exports.userState = function userState(state) {
  return state.user;
};
var token = exports.token = (0, _reselect.createSelector)(userState, function (user) {
  return user.get('token');
});
var isLoading = exports.isLoading = (0, _reselect.createSelector)(userState, function (user) {
  return user.get('isLoading');
});
var isAuth = exports.isAuth = (0, _reselect.createSelector)(userState, function (user) {
  return user.get('isAuth');
});
var username = exports.username = (0, _reselect.createSelector)(userState, function (user) {
  return user.get('username');
});
var spending = exports.spending = (0, _reselect.createSelector)(userState, function (user) {
  return user.get('spending').get('list');
});
var receiving = exports.receiving = (0, _reselect.createSelector)(userState, function (user) {
  return user.get('receiving').get('list');
});
var operations = exports.operations = (0, _reselect.createSelector)([spending, receiving], function (spending, receiving) {
  return spending.map(function (sp) {
    return new _Operation2.default({
      type: 'debit',
      id: 'debit' + sp.get('id'),
      date: sp.get('created_at') || null,
      description: (0, _immutable.Map)({
        icon: sp.get('icon') || 'default',
        text: sp.get('name') || null,
        account: sp.get('parent_id') || null
      }),
      percentage: 0,
      amount: 0
    });
  }).concat(receiving.map(function (rec) {
    return new _Operation2.default({
      type: 'credit',
      id: 'credit' + rec.get('id'),
      date: rec.get('created_at') || null,
      description: (0, _immutable.Map)({
        icon: rec.get('icon') || 'default',
        text: rec.get('name') || null,
        account: null
      }),
      percentage: 0,
      amount: 0
    });
  }));
});