'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.auth = undefined;

var _reduxForm = require('redux-form');

var _get = require('lodash/get');

var _get2 = _interopRequireDefault(_get);

var _actions = require('../actions');

var _actions2 = require('../../versions/actions');

var _actions3 = require('../../notifications/actions');

var _actions4 = require('../../analytics/actions');

var _helpers = require('../../../helpers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

/**
 * Auth user (login or register)
 * @exports user:auth
 * @param {User} user - Данные для отправки на сервер
 * @param {string} formName - имя формы
 * @example
 * import { reduxForm, SubmissionError } from 'redux-form'
 * import { auth } from 'ratio-v-store/user';
 * reduxForm({
 *   onSubmit: (data, dispatch) => dispatch(auth({ ...data, isLogin: true }, FORM_NAME))
 *     .catch(err => {throw new SubmissionError(err.errors)}),
 *   onSubmitSuccess(result, dispatch, { navigation }) {
 *     if (result && result.payload) {
 *       // successfully login/register
 *     }
 *   },
 * })(LoginForm)
 */
var auth = exports.auth = function auth(user, formName) {
  return function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(dispatch) {
      var response, errorData;
      return regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.prev = 0;

              dispatch((0, _reduxForm.startSubmit)(formName));
              response = void 0;

              if (!user.isLogin) {
                _context.next = 9;
                break;
              }

              _context.next = 6;
              return dispatch((0, _actions.loginUser)(user));

            case 6:
              response = _context.sent;
              _context.next = 12;
              break;

            case 9:
              _context.next = 11;
              return dispatch((0, _actions.registerUser)(user));

            case 11:
              response = _context.sent;

            case 12:
              if (!response.error) {
                _context.next = 19;
                break;
              }

              dispatch(_actions3.notify.error(user.isLogin ? 'Login failed' : 'Registration failed'));
              dispatch((0, _reduxForm.stopSubmit)(formName, (0, _helpers.getErrors)(response)));
              errorData = (0, _get2.default)(response, ['error', 'response', 'data']);
              throw new _reduxForm.SubmissionError(errorData ? errorData.reduce(function (res, el) {
                res[el.field] = el.message;
                return res;
              }, {}) : { _error: 'Unknown Error' });

            case 19:
              dispatch((0, _actions2.onVersionsUpdate)());
              dispatch(_actions3.notify.success(user.isLogin ? 'Login Success!' : 'Register Success!'));
              dispatch((0, _reduxForm.stopSubmit)(formName));

            case 22:
              return _context.abrupt('return', response);

            case 25:
              _context.prev = 25;
              _context.t0 = _context['catch'](0);

              dispatch(_actions4.analytics.error(_context.t0, 'Auth Action'));
              dispatch(_actions3.notify.error('Unknown Error'));
              throw _context.t0;

            case 30:
            case 'end':
              return _context.stop();
          }
        }
      }, _callee, undefined, [[0, 25]]);
    }));

    return function (_x) {
      return _ref.apply(this, arguments);
    };
  }();
};