'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.UserTransactions = exports.Transaction = undefined;

var _immutable = require('immutable');

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * Данные, описывающие транзакцию Transaction
 * @typedef {Object} Transaction
 * @property {?int} id - id определяется сервером
 * @property {?int} sequence_number - порядковый номер транзакции (должны следовать строго по-порядку для заданного счета)
 * @property {!double} amount - сумма транзакции в валюте назначения платежа(перевода)
 * @property {!int} user_ratio_id - указатель на счет, откуда производится зачисление
 * @property {!int} user_ratio_currency_id - указатель на валюту счета на момент операции (валюта счета может меняться)
 * @property {!int} entity_type_id - указатель на тип сущности, куда производится зачисление (другой счет, растрата)
 * @property {!int} entity_id - указатель на сущность, куда производится зачисление (это может быть указатель счета,
 *      если это перевод)
 * @property {!int} entity_currency_id - указатель на валюту сущности, куда происходит зачисление на момент операции
 * @property {?double} exchange_rate - курс конвертации, если валюты счета и назначения не совпадают валюта счета/валюту
 *      назначения, если не указан то возьмется из глобального значения, если глобальное значение не задано
 *      (или не подтянулось автоматически), должны попросить указать это значение
 * @property {?date} date - дата операции, записанная пользователем (используется только для отображения пользователю)
 * @property {?date} created_at - фактическая дата произведения операции
 *      (может использоваться для защищенных операций и определяется сервером)
 * @property {?string} description - описание назначения транзакции (необязательное поле)
 * @property {?double} previous_balance - предыдущий балланс счета до произведения операции
 * @property {?boolean} is_editable - указатель на то, может ли пользователь самостоятельно редактировать этот счет
 */
var TransactionRecord = (0, _immutable.Record)({
  id: null,
  sequence_number: null,
  amount: null,
  user_ratio_id: null,
  user_ratio_currency_id: null,
  entity_type_id: null,
  entity_id: null,
  entity_currency_id: null,
  exchange_rate: 1,
  date: null,
  created_at: null,
  description: null,
  previous_balance: 0,
  is_editable: null
}, 'Transaction');

var Transaction = exports.Transaction = function (_TransactionRecord) {
  _inherits(Transaction, _TransactionRecord);

  function Transaction() {
    _classCallCheck(this, Transaction);

    return _possibleConstructorReturn(this, (Transaction.__proto__ || Object.getPrototypeOf(Transaction)).apply(this, arguments));
  }

  return Transaction;
}(TransactionRecord);

var UserTransactionsRecord = (0, _immutable.Record)({
  isLoading: false,
  list: (0, _immutable.List)()
}, 'UserTransactions');

var UserTransactions = exports.UserTransactions = function (_UserTransactionsReco) {
  _inherits(UserTransactions, _UserTransactionsReco);

  function UserTransactions() {
    _classCallCheck(this, UserTransactions);

    return _possibleConstructorReturn(this, (UserTransactions.__proto__ || Object.getPrototypeOf(UserTransactions)).apply(this, arguments));
  }

  return UserTransactions;
}(UserTransactionsRecord);