'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.sectors = exports.spendingSum = exports.spending = exports.lastTransaction = exports.transactions = undefined;

var _reselect = require('reselect');

var _Sector = require('./Sector');

var _constants = require('./constants');

var baseState = function baseState(state) {
  return state.user.transactions;
};
var transactions = exports.transactions = (0, _reselect.createSelector)(baseState, function (transactions) {
  return transactions.get('list');
});
var lastTransaction = exports.lastTransaction = (0, _reselect.createSelector)(transactions, function (transactions) {
  return transactions.last();
});

var spending = exports.spending = (0, _reselect.createSelector)(transactions, function (transactions) {
  return transactions.filter(function (el) {
    return el.entity_type_id === _constants.SPENDING_TYPE;
  }).groupBy(function (el) {
    return el.entity_id;
  }).map(function (el) {
    return el.reduce(function (res, el) {
      return res += el.amount;
    }, 0);
  });
});

var spendingSum = exports.spendingSum = (0, _reselect.createSelector)(spending, function (sp) {
  return sp.reduce(function (res, el) {
    return res += el;
  }, 0);
});

/**
 * Select sectors for rendering Round Chart
 * @exports sectors
 * @return {Sector[]} - возвращает массив записей секторов с ифнормацией для отображения на графике
 * @example
 * import { sectors } from 'ratio-v-store/user/transactions';
 * const mapStateToProps = state => ({
 *   sectors: sectors(state),
 * })
 *
 * // и потом используем для рендера:
 * <div>
 *   {sectors.map({ category_id, amount, startAngle, endAngle, angle } => (
 *     <div>
 *       <p>Категория - {category_id}</p>
 *       <p>Сумма - {amount}</p>
 *       <p>Стартовый угол - {startAngle}</p>
 *       <p>Конечный угол - {endAngle}</p>
 *       <p>Средний угол - {angle}</p>
 *     </div>
 *   ))}
 * </div>
 */
var sectors = exports.sectors = (0, _reselect.createSelector)([spending, spendingSum], function (sp, sum) {
  var currentAngle = 0;
  return sp.map(function (el, key) {
    var startAngle = currentAngle;
    currentAngle = el / sum * 2 * Math.PI + currentAngle;
    return new _Sector.Sector({
      category_id: key,
      amount: el,
      startAngle: startAngle,
      endAngle: currentAngle,
      angle: (startAngle + currentAngle) / 2
    });
  }).toList();
});